==> handi-0.6.7.tar.gz: handi-0.6.7/handy/cli/crypt.py <==
import sys
import hashlib

msg_help_hash = "Written by junying, 2019-05-02 \
                \nUsage: hash [string] "                   
def hash():
    if len(sys.argv) < 2: print(msg_help_hash); return
    print(hashlib.sha224(sys.argv[1]).hexdigest())

from handy.crypto.encode import encode, decode

msg_help_encode = "Written by junying, 2019-05-02 \
                  \nUsage: encode [string] "    
                
def Encode():
    if len(sys.argv) < 2: print(msg_help_encode); return
    print(encode(sys.argv[1]))
    
msg_help_decode = "Written by junying, 2019-05-02 \
                  \nUsage: decode [string] "    
                
def Decode():
    if len(sys.argv) < 2: print(msg_help_decode); return
    print(decode(sys.argv[1]))
    
from handy.crypto.encrypt import encrypt,decrypt

msg_help_encrypt = "Written by junying, 2019-05-02 \
                  \nUsage: encrypt [string] [password] "    
msg_passwd = "enter pasword: "

def Encrypt():
    if len(sys.argv) < 2: print(msg_help_encrypt); return
    elif len(sys.argv) == 2: password = raw_input(msg_passwd) if sys.version_info[0] == 2 else input(msg_passwd)
    else: password = sys.argv[2]
    print(encrypt(sys.argv[1],password))

msg_help_decrypt = "Written by junying, 2019-05-02 \
                  \nUsage: decrypt [string] [password] "   
                      
def Decrypt():
    if len(sys.argv) < 2: print(msg_help_decrypt); return
    elif len(sys.argv) == 2: password = raw_input(msg_passwd) if sys.version_info[0] == 2 else input(msg_passwd)
    else: password = sys.argv[2]
    print(decrypt(sys.argv[1],password))

==> handi-0.8.4.tar.gz: handi-0.8.4/handy/cli/crypt.py <==
import sys
import hashlib

msg_help_hash = "Written by junying, 2019-05-02 \
                \nUsage: hash [string] "                   
def hash():
    if len(sys.argv) < 2: print(msg_help_hash); return
    print(hashlib.sha224(sys.argv[1]).hexdigest())

from handy.crypto.encode import encode, decode

msg_help_encode = "Written by junying, 2019-05-02 \
                  \nUsage: encode [string] "    
                
def Encode():
    if len(sys.argv) < 2: print(msg_help_encode); return
    print(encode(sys.argv[1]))
    
msg_help_decode = "Written by junying, 2019-05-02 \
                  \nUsage: decode [string] "    
                
def Decode():
    if len(sys.argv) < 2: print(msg_help_decode); return
    print(decode(sys.argv[1]))
    
from handy.crypto.encrypt import encrypt,decrypt

msg_help_encrypt = "Written by junying, 2019-05-02 \
                  \nUsage: encrypt [string] [password] "    


from getpass import getpass
from .constants import msg_passwd

def Encrypt():
    if len(sys.argv) < 2: print(msg_help_encrypt); return
    elif len(sys.argv) == 2: password = getpass(msg_passwd)
    else: password = sys.argv[2]
    print(encrypt(sys.argv[1],password))

msg_help_decrypt = "Written by junying, 2019-05-02 \
                  \nUsage: decrypt [string] [password] "   
                      
def Decrypt():
    if len(sys.argv) < 2: print(msg_help_decrypt); return
    elif len(sys.argv) == 2: password = getpass(msg_passwd)
    else: password = sys.argv[2]
    print(decrypt(sys.argv[1],password))
